TODO:

- [ ] make the end-to-end API
- [ ] restructure + lint code
- [ ] better readme
- [ ] reproduce BOCPD


- [ ] add [univaritebocpd](https://github.com/phamquiluan/BOCPD/commit/975eef0abef32e8ab06cf48908d0a6325234de8e)
- [ ] add RobustBOCPD + add tuts
- [ ] make a Helm chart
